@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Headers
 
@@ -190,7 +194,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
 void WebPriceQuote::removeTempFile(const TQString& tmpFile)
 {
   if(tmpFile == m_tmpFile) {
-    unlink(tmpFile);
+    unlink(tmpFile.local8Bit());
     m_tmpFile = TQString();
   }
 }
@@ -831,7 +835,7 @@ void FinanceQuoteProcess::slotProcessExited(TDEProcess*)
 void FinanceQuoteProcess::launch (const TQString& scriptPath) {
   clearArguments();
   arguments.append(TQCString("perl"));
-  arguments.append (TQCString(scriptPath));
+  arguments.append (scriptPath.local8Bit());
   arguments.append (TQCString("-l"));
   if (!start(TDEProcess::NotifyOnExit, TDEProcess::Stdout)) tqFatal ("Unable to start FQ script");
   return;
