@@ -16,10 +16,6 @@
 #ifndef KMYMONEY2_H
 #define KMYMONEY2_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
