@@ -40,6 +40,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 #include <tqstring.h>
@@ -52,7 +56,6 @@
 
 // ----------------------------------------------------------------------------
 // KDE Includes
-#include "kdecompat.h"
 #include <tdeglobal.h>
 #include <tdeglobalsettings.h>
 #include <tdelocale.h>
