@@ -26,6 +26,11 @@
  ** licensing are not clear to you.
  **
  **********************************************************************/
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "KDChartLinesPainter.h"
 #include <KDChartParams.h>
 #include <KDChartPropertySet.h>
